@@ -27,6 +27,7 @@ import org.apache.skywalking.apm.agent.core.logging.api.ILog;
 import org.apache.skywalking.apm.agent.core.logging.api.LogManager;
 import org.apache.skywalking.apm.agent.core.plugin.interceptor.enhance.OverrideCallable;
 import org.apache.skywalking.apm.agent.core.plugin.loader.InterceptorInstanceLoader;
+import org.apache.skywalking.apm.agent.core.so11y.AgentSo11y;
 
 /**
  * The actual byte-buddy's interceptor to intercept class instance methods. In this class, it provides a bridge between
@@ -35,6 +36,9 @@ import org.apache.skywalking.apm.agent.core.plugin.loader.InterceptorInstanceLoa
 public class StaticMethodsInterV2WithOverrideArgs {
     private static final ILog LOGGER = LogManager.getLogger(StaticMethodsInterV2WithOverrideArgs.class);
 
+    private static final String INTERCEPTOR_TYPE = "static";
+
+    private String pluginName;
     /**
      * A class full name, and instanceof {@link StaticMethodsAroundInterceptorV2} This name should only stay in {@link
      * String}, the real {@link Class} type will trigger classloader failure. If you want to know more, please check on
@@ -47,7 +51,8 @@ public class StaticMethodsInterV2WithOverrideArgs {
      *
      * @param staticMethodsAroundInterceptorClassName class full name.
      */
-    public StaticMethodsInterV2WithOverrideArgs(String staticMethodsAroundInterceptorClassName) {
+    public StaticMethodsInterV2WithOverrideArgs(String pluginName, String staticMethodsAroundInterceptorClassName) {
+        this.pluginName = pluginName;
         this.staticMethodsAroundInterceptorClassName = staticMethodsAroundInterceptorClassName;
     }
 
@@ -68,12 +73,16 @@ public class StaticMethodsInterV2WithOverrideArgs {
         StaticMethodsAroundInterceptorV2 interceptor = InterceptorInstanceLoader.load(staticMethodsAroundInterceptorClassName,
                                                                                       clazz.getClassLoader());
 
+        long interceptorTimeCost = 0L;
+        long startTimeOfMethodBeforeInter = System.nanoTime();
         MethodInvocationContext context = new MethodInvocationContext();
         try {
             interceptor.beforeMethod(clazz, method, allArguments, method.getParameterTypes(), context);
         } catch (Throwable t) {
             LOGGER.error(t, "class[{}] before static method[{}] intercept failure", clazz, method.getName());
+            AgentSo11y.errorOfPlugin(pluginName, INTERCEPTOR_TYPE);
         }
+        interceptorTimeCost += System.nanoTime() - startTimeOfMethodBeforeInter;
 
         Object ret = null;
         try {
@@ -83,19 +92,27 @@ public class StaticMethodsInterV2WithOverrideArgs {
                 ret = zuper.call(allArguments);
             }
         } catch (Throwable t) {
+            long startTimeOfMethodHandleExceptionInter = System.nanoTime();
             try {
                 interceptor.handleMethodException(clazz, method, allArguments, method.getParameterTypes(), t, context);
             } catch (Throwable t2) {
                 LOGGER.error(t2, "class[{}] handle static method[{}] exception failure", clazz, method.getName(), t2.getMessage());
+                AgentSo11y.errorOfPlugin(pluginName, INTERCEPTOR_TYPE);
             }
+            interceptorTimeCost += System.nanoTime() - startTimeOfMethodHandleExceptionInter;
             throw t;
         } finally {
+            long startTimeOfMethodAfterInter = System.nanoTime();
             try {
                 ret = interceptor.afterMethod(clazz, method, allArguments, method.getParameterTypes(), ret, context);
             } catch (Throwable t) {
                 LOGGER.error(t, "class[{}] after static method[{}] intercept failure:{}", clazz, method.getName(), t.getMessage());
+                AgentSo11y.errorOfPlugin(pluginName, INTERCEPTOR_TYPE);
             }
+            interceptorTimeCost += System.nanoTime() - startTimeOfMethodAfterInter;
         }
+        AgentSo11y.durationOfInterceptor(interceptorTimeCost);
+
         return ret;
     }
 }
