@@ -23,6 +23,7 @@ import org.apache.skywalking.apm.agent.core.context.ContextManager;
 import org.apache.skywalking.apm.agent.core.context.tag.Tags;
 import org.apache.skywalking.apm.agent.core.context.trace.AbstractSpan;
 import org.apache.skywalking.apm.agent.core.context.trace.SpanLayer;
+import org.apache.skywalking.apm.plugin.jdbc.SqlBodyUtil;
 
 /**
  * {@link PreparedStatementTracing} create an exit span when the client call the method in the class that extend {@link
@@ -36,7 +37,7 @@ public class StatementTracing {
                 .getDatabasePeer());
             Tags.DB_TYPE.set(span, connectInfo.getDBType());
             Tags.DB_INSTANCE.set(span, connectInfo.getDatabaseName());
-            Tags.DB_STATEMENT.set(span, sql);
+            Tags.DB_STATEMENT.set(span, SqlBodyUtil.limitSqlBodySize(sql));
             span.setComponent(connectInfo.getComponent());
             SpanLayer.asDB(span);
             return exec.exe(realStatement, sql);
