@@ -18,6 +18,9 @@
 
 package org.apache.skywalking.apm.plugin.spring.mvc.commons.interceptor;
 
+import java.lang.reflect.Method;
+import javax.servlet.http.HttpServletRequest;
+import javax.servlet.http.HttpServletResponse;
 import org.apache.skywalking.apm.agent.core.context.CarrierItem;
 import org.apache.skywalking.apm.agent.core.context.ContextCarrier;
 import org.apache.skywalking.apm.agent.core.context.ContextManager;
@@ -34,6 +37,8 @@ import org.apache.skywalking.apm.agent.core.util.CollectionUtil;
 import org.apache.skywalking.apm.agent.core.util.MethodUtil;
 import org.apache.skywalking.apm.network.trace.component.ComponentsDefine;
 import org.apache.skywalking.apm.plugin.spring.mvc.commons.EnhanceRequireObjectCache;
+import org.apache.skywalking.apm.plugin.spring.mvc.commons.HttpServletRequestWrapper;
+import org.apache.skywalking.apm.plugin.spring.mvc.commons.HttpServletRequestWrappers;
 import org.apache.skywalking.apm.plugin.spring.mvc.commons.RequestUtil;
 import org.apache.skywalking.apm.plugin.spring.mvc.commons.SpringMVCPluginConfig;
 import org.apache.skywalking.apm.plugin.spring.mvc.commons.exception.IllegalMethodStackDepthException;
@@ -41,10 +46,6 @@ import org.apache.skywalking.apm.plugin.spring.mvc.commons.exception.ServletResp
 import org.springframework.http.server.reactive.ServerHttpRequest;
 import org.springframework.http.server.reactive.ServerHttpResponse;
 
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
-import java.lang.reflect.Method;
-
 import static org.apache.skywalking.apm.plugin.spring.mvc.commons.Constants.CONTROLLER_METHOD_STACK_DEPTH;
 import static org.apache.skywalking.apm.plugin.spring.mvc.commons.Constants.FORWARD_REQUEST_FLAG;
 import static org.apache.skywalking.apm.plugin.spring.mvc.commons.Constants.REACTIVE_ASYNC_SPAN_IN_RUNTIME_CONTEXT;
@@ -68,10 +69,11 @@ public abstract class AbstractMethodInterceptor implements InstanceMethodsAround
 
     static {
         IS_SERVLET_GET_STATUS_METHOD_EXIST = MethodUtil.isMethodExist(
-                AbstractMethodInterceptor.class.getClassLoader(), SERVLET_RESPONSE_CLASS, GET_STATUS_METHOD);
+            AbstractMethodInterceptor.class.getClassLoader(), SERVLET_RESPONSE_CLASS, GET_STATUS_METHOD);
         IS_JAKARTA_SERVLET_GET_STATUS_METHOD_EXIST = MethodUtil.isMethodExist(
-                AbstractMethodInterceptor.class.getClassLoader(),
-            JAKARTA_SERVLET_RESPONSE_CLASS, GET_STATUS_METHOD);
+            AbstractMethodInterceptor.class.getClassLoader(),
+            JAKARTA_SERVLET_RESPONSE_CLASS, GET_STATUS_METHOD
+        );
         try {
             Class.forName(SERVLET_RESPONSE_CLASS, true, AbstractMethodInterceptor.class.getClassLoader());
             IN_SERVLET_CONTAINER = true;
@@ -113,53 +115,15 @@ public abstract class AbstractMethodInterceptor implements InstanceMethodsAround
 
                 if (IN_SERVLET_CONTAINER && IS_JAVAX && HttpServletRequest.class.isAssignableFrom(request.getClass())) {
                     final HttpServletRequest httpServletRequest = (HttpServletRequest) request;
-                    CarrierItem next = contextCarrier.items();
-                    while (next.hasNext()) {
-                        next = next.next();
-                        next.setHeadValue(httpServletRequest.getHeader(next.getHeadKey()));
-                    }
+                    handleBeforeMethod(
+                        objInst, method, HttpServletRequestWrappers.wrap(httpServletRequest), contextCarrier);
 
-                    String operationName = this.buildOperationName(method, httpServletRequest.getMethod(),
-                                                                   (EnhanceRequireObjectCache) objInst.getSkyWalkingDynamicField());
-                    AbstractSpan span = ContextManager.createEntrySpan(operationName, contextCarrier);
-                    Tags.URL.set(span, httpServletRequest.getRequestURL().toString());
-                    Tags.HTTP.METHOD.set(span, httpServletRequest.getMethod());
-                    span.setComponent(ComponentsDefine.SPRING_MVC_ANNOTATION);
-                    SpanLayer.asHttp(span);
-
-                    if (SpringMVCPluginConfig.Plugin.SpringMVC.COLLECT_HTTP_PARAMS) {
-                        RequestUtil.collectHttpParam(httpServletRequest, span);
-                    }
-
-                    if (!CollectionUtil.isEmpty(SpringMVCPluginConfig.Plugin.Http.INCLUDE_HTTP_HEADERS)) {
-                        RequestUtil.collectHttpHeaders(httpServletRequest, span);
-                    }
-                } else if (IN_SERVLET_CONTAINER && IS_JAKARTA && jakarta.servlet.http.HttpServletRequest.class.isAssignableFrom(request.getClass())) {
+                } else if (IN_SERVLET_CONTAINER && IS_JAKARTA && jakarta.servlet.http.HttpServletRequest.class.isAssignableFrom(
+                    request.getClass())) {
                     final jakarta.servlet.http.HttpServletRequest httpServletRequest = (jakarta.servlet.http.HttpServletRequest) request;
-                    CarrierItem next = contextCarrier.items();
-                    while (next.hasNext()) {
-                        next = next.next();
-                        next.setHeadValue(httpServletRequest.getHeader(next.getHeadKey()));
-                    }
+                    handleBeforeMethod(
+                        objInst, method, HttpServletRequestWrappers.wrap(httpServletRequest), contextCarrier);
 
-                    String operationName =
-                        this.buildOperationName(method, httpServletRequest.getMethod(),
-                            (EnhanceRequireObjectCache) objInst.getSkyWalkingDynamicField());
-                    AbstractSpan span =
-                        ContextManager.createEntrySpan(operationName, contextCarrier);
-                    Tags.URL.set(span, httpServletRequest.getRequestURL().toString());
-                    Tags.HTTP.METHOD.set(span, httpServletRequest.getMethod());
-                    span.setComponent(ComponentsDefine.SPRING_MVC_ANNOTATION);
-                    SpanLayer.asHttp(span);
-
-                    if (SpringMVCPluginConfig.Plugin.SpringMVC.COLLECT_HTTP_PARAMS) {
-                        RequestUtil.collectHttpParam(httpServletRequest, span);
-                    }
-
-                    if (!CollectionUtil
-                        .isEmpty(SpringMVCPluginConfig.Plugin.Http.INCLUDE_HTTP_HEADERS)) {
-                        RequestUtil.collectHttpHeaders(httpServletRequest, span);
-                    }
                 } else if (ServerHttpRequest.class.isAssignableFrom(request.getClass())) {
                     final ServerHttpRequest serverHttpRequest = (ServerHttpRequest) request;
                     CarrierItem next = contextCarrier.items();
@@ -168,8 +132,10 @@ public abstract class AbstractMethodInterceptor implements InstanceMethodsAround
                         next.setHeadValue(serverHttpRequest.getHeaders().getFirst(next.getHeadKey()));
                     }
 
-                    String operationName = this.buildOperationName(method, serverHttpRequest.getMethod().name(),
-                                                                   (EnhanceRequireObjectCache) objInst.getSkyWalkingDynamicField());
+                    String operationName = this.buildOperationName(
+                        method, serverHttpRequest.getMethod().name(),
+                        (EnhanceRequireObjectCache) objInst.getSkyWalkingDynamicField()
+                    );
                     AbstractSpan span = ContextManager.createEntrySpan(operationName, contextCarrier);
                     Tags.URL.set(span, serverHttpRequest.getURI().toString());
                     Tags.HTTP.METHOD.set(span, serverHttpRequest.getMethod().name());
@@ -198,6 +164,31 @@ public abstract class AbstractMethodInterceptor implements InstanceMethodsAround
         }
     }
 
+    private void handleBeforeMethod(EnhancedInstance objInst, Method method,
+                                    HttpServletRequestWrapper httpServletRequest, ContextCarrier contextCarrier) {
+        CarrierItem next = contextCarrier.items();
+        while (next.hasNext()) {
+            next = next.next();
+            next.setHeadValue(httpServletRequest.getHeader(next.getHeadKey()));
+        }
+
+        String operationName = this.buildOperationName(
+            method, httpServletRequest.getMethod(), (EnhanceRequireObjectCache) objInst.getSkyWalkingDynamicField());
+        AbstractSpan span = ContextManager.createEntrySpan(operationName, contextCarrier);
+        Tags.URL.set(span, httpServletRequest.getRequestURL().toString());
+        Tags.HTTP.METHOD.set(span, httpServletRequest.getMethod());
+        span.setComponent(ComponentsDefine.SPRING_MVC_ANNOTATION);
+        SpanLayer.asHttp(span);
+
+        if (SpringMVCPluginConfig.Plugin.SpringMVC.COLLECT_HTTP_PARAMS) {
+            RequestUtil.collectHttpParam(httpServletRequest, span);
+        }
+
+        if (!CollectionUtil.isEmpty(SpringMVCPluginConfig.Plugin.Http.INCLUDE_HTTP_HEADERS)) {
+            RequestUtil.collectHttpHeaders(httpServletRequest, span);
+        }
+    }
+
     @Override
     public Object afterMethod(EnhancedInstance objInst, Method method, Object[] allArguments, Class<?>[] argumentsTypes,
                               Object ret) throws Throwable {
@@ -232,9 +223,11 @@ public abstract class AbstractMethodInterceptor implements InstanceMethodsAround
 
                     Integer statusCode = null;
 
-                    if (IS_SERVLET_GET_STATUS_METHOD_EXIST && HttpServletResponse.class.isAssignableFrom(response.getClass())) {
+                    if (IS_SERVLET_GET_STATUS_METHOD_EXIST && HttpServletResponse.class.isAssignableFrom(
+                        response.getClass())) {
                         statusCode = ((HttpServletResponse) response).getStatus();
-                    } else if (IS_JAKARTA_SERVLET_GET_STATUS_METHOD_EXIST && jakarta.servlet.http.HttpServletResponse.class.isAssignableFrom(response.getClass())) {
+                    } else if (IS_JAKARTA_SERVLET_GET_STATUS_METHOD_EXIST && jakarta.servlet.http.HttpServletResponse.class.isAssignableFrom(
+                        response.getClass())) {
                         statusCode = ((jakarta.servlet.http.HttpServletResponse) response).getStatus();
                     } else if (ServerHttpResponse.class.isAssignableFrom(response.getClass())) {
                         if (IS_SERVLET_GET_STATUS_METHOD_EXIST || IS_JAKARTA_SERVLET_GET_STATUS_METHOD_EXIST) {
@@ -263,7 +256,8 @@ public abstract class AbstractMethodInterceptor implements InstanceMethodsAround
                 if (!SpringMVCPluginConfig.Plugin.SpringMVC.COLLECT_HTTP_PARAMS && span.isProfiling()) {
                     if (IS_JAVAX && HttpServletRequest.class.isAssignableFrom(request.getClass())) {
                         RequestUtil.collectHttpParam((HttpServletRequest) request, span);
-                    } else if (IS_JAKARTA && jakarta.servlet.http.HttpServletRequest.class.isAssignableFrom(request.getClass())) {
+                    } else if (IS_JAKARTA && jakarta.servlet.http.HttpServletRequest.class.isAssignableFrom(
+                        request.getClass())) {
                         RequestUtil.collectHttpParam((jakarta.servlet.http.HttpServletRequest) request, span);
                     } else if (ServerHttpRequest.class.isAssignableFrom(request.getClass())) {
                         RequestUtil.collectHttpParam((ServerHttpRequest) request, span);
@@ -309,7 +303,7 @@ public abstract class AbstractMethodInterceptor implements InstanceMethodsAround
                 pathMappingCache.addPathMapping(method, requestURL);
                 requestURL = pathMappingCache.findPathMapping(method);
             }
-            operationName =  String.join(":", httpMethod, requestURL);
+            operationName = String.join(":", httpMethod, requestURL);
         }
 
         return operationName;
