@@ -23,7 +23,7 @@ public class ServerWebExchangeInstrumentation extends org.apache.skywalking.apm.
     @Override
     protected String[] witnessClasses() {
         return new String[] {
-            "org.springframework.cloud.gateway.config.GatewayAutoConfiguration$1"
+            "org.springframework.cloud.gateway.config.GatewayAutoConfiguration"
         };
     }
 }
