@@ -18,13 +18,16 @@
 
 package org.apache.skywalking.apm.testcase.jedis.controller;
 
+import redis.clients.jedis.DefaultJedisSocketFactory;
 import redis.clients.jedis.Jedis;
+import redis.clients.jedis.JedisSocketFactory;
 
 public class RedisCommandExecutor implements AutoCloseable {
     private Jedis jedis;
 
     public RedisCommandExecutor(String host, Integer port) {
-        jedis = new Jedis(host, port);
+        JedisSocketFactory jedisSocketFactory = new DefaultJedisSocketFactory(host, port, 1000, 1000, false, null, null, null);
+        jedis = new Jedis(jedisSocketFactory);
         jedis.echo("Test");
     }
 
